@@ -14,6 +14,7 @@ Thank you, Kurt Jacobson!
 """
 
 import argparse
+import stat
 import sys
 import threading
 import gi
@@ -1104,6 +1105,32 @@ def main():
     elif hypr:
         if os.path.isdir(hypr_config_dir):
             outputs_path = args.monitors_path
+            # 97, 115
+            if os.path.lexists(outputs_path):
+                is_writable = os.access(outputs_path, os.W_OK)
+                if os.path.islink(outputs_path) and not is_writable:
+                    eprint(f"INFO: '{outputs_path}' is a read-only symlink. Replacing with a writable file.")
+                    tmp_path = f"{outputs_path}.tmp"
+                    try:
+                        with open(outputs_path, 'r') as src_file, open(tmp_path, 'w') as tmp_file:
+                            tmp_file.write(src_file.read())
+                        backup_path = f"{outputs_path}.bkp"
+                        counter = 1
+                        while os.path.lexists(backup_path):
+                            backup_path = f"{outputs_path}.bkp{counter}"
+                            counter += 1
+                        eprint(f"INFO: Backing up '{outputs_path}' to '{backup_path}'")
+                        os.rename(outputs_path, backup_path)
+                        os.rename(tmp_path, outputs_path)
+                    except Exception as e:
+                        eprint(f"ERROR: Failed to replace read-only symlink: {e}")
+                elif not os.path.islink(outputs_path) and not is_writable:
+                    eprint(f"INFO: '{outputs_path}' is a read-only file. Making it writable.")
+                    try:
+                        os.chmod(outputs_path, os.stat(outputs_path).st_mode | stat.S_IWUSR)
+                    except Exception as e:
+                        eprint(f"ERROR: Failed to make file writable: {e}")
+
             workspaces_path = args.workspaces_path
         else:
             eprint("Hyprland config directory not found!")
@@ -1277,6 +1304,7 @@ def main():
 
     global form_modes
     form_modes = builder.get_object("modes")
+    form_modes.set_wrap_width(1)
     form_modes.set_tooltip_text(voc["modes-tooltip"])
     form_modes.connect("changed", on_mode_changed)
 
@@ -1288,6 +1316,7 @@ def main():
 
     global form_transform
     form_transform = builder.get_object("transform")
+    form_transform.set_wrap_width(1)
     form_transform.set_tooltip_text(voc["transform-tooltip"])
     form_transform.connect("changed", on_transform_changed)
 
@@ -1350,6 +1379,25 @@ def main():
     else:
         btn.destroy()
 
+    if hypr:
+        grid = builder.get_object("grid")
+
+        global form_ten_bit
+        form_ten_bit = Gtk.CheckButton.new_with_label(voc["10-bit-support"])
+        form_ten_bit.set_tooltip_text(voc["10-bit-support-tooltip"])
+        form_ten_bit.connect("toggled", on_ten_bit_toggled)
+        grid.attach(form_ten_bit, 5, 4, 1, 1)
+
+        lbl = Gtk.Label.new("Mirror:")
+        lbl.set_property("halign", Gtk.Align.END)
+        grid.attach(lbl, 6, 4, 1, 1)
+
+        global form_mirror
+        form_mirror = Gtk.ComboBoxText()
+        form_mirror.set_wrap_width(1)
+        form_mirror.connect("changed", on_mirror_selected)
+        grid.attach(form_mirror, 7, 4, 1, 1)
+
     # Add profile management buttons
     separator = Gtk.Separator(orientation=Gtk.Orientation.VERTICAL)
     form_wrapper_box.pack_start(separator, False, False, 10)
